.. _cli_jobs_list:

qbraid jobs list
=================

Get list of qBraid Quantum Jobs.

.. code-block:: bash

    qbraid jobs list


Examples
---------

.. code-block:: console

    $ qbraid jobs list
    Thu Mar 02 2023 18:16:10 GMT+0000 (Coordinated Universal Time) arn:aws:braket:::device/quantum-simulator/amazon/sv1 arn:aws:braket:us-east-1:xxxxxxxxxxxx:quantum-task/yyyyyyyy-yyyy-yyyy-yyyy-yyyyyyyyyyyy
    ...


.. seealso::

    - :ref:`qbraid jobs enable<cli_jobs_enable>`
    - :ref:`qbraid jobs disable<cli_jobs_disable>`